Basically i glued Peter Drescher and Simon Ford libs in a GraphicsDisplay class, then derived TFT or LCD class (which inherits Protocols class), then the most derived ones (Inits), which are per-display and are the only part needed to be adapted to diff hw.

Dependents:   testUniGraphic_150217 maze_TFT_MMA8451Q TFT_test_frdm-kl25z TFT_test_NUCLEO-F411RE ... more

Revision:
3:48f3282c2be8
Parent:
1:ff019d22b275
Child:
4:12ba0ecc2c1f
--- a/Inits/UC1608.cpp	Fri Feb 13 23:17:55 2015 +0000
+++ b/Inits/UC1608.cpp	Sat Feb 14 17:42:21 2015 +0000
@@ -52,8 +52,8 @@
     wait_ms(10);
     
    // wr_cmd8(0x81);//Set Gain and Potentiometer
-  //  wr_cmd8(0x40|46);//Set Gain and Potentiometer  xx xxxxxx
-    set_contrast(46);
+  //  wr_cmd8(0x40|26);//Set Gain and Potentiometer  xx xxxxxx
+    set_contrast(26);
     
     wr_cmd8(0x88);   //disable colum/page address wraparound
     wr_cmd8(0xA4);   //  LCD display ram (EntireDisplayOn disable)